package space.rocketnine.gophast;

import android.os.AsyncTask;
import android.os.Handler;
import android.os.Looper;
import android.util.Log;

import manager.Manager;
import manager.NewDownloadInfo;

class DownloadTask extends AsyncTask<Download, Long, Long> {
    Runnable onFinish;
    Download download;
    Handler handler;
    GoPhast gophast;

    @Override
    protected Long doInBackground(Download... downloads) {
        if (handler == null) {
            Looper.prepare();
            handler = new Handler(Looper.getMainLooper());
        }

        int count = downloads.length;
        long size = 0;
        for (Download d : downloads) {
            download = d;
            try {
                Log.d("gophast", "Initiating download " + download.URL);
                NewDownloadInfo info = new NewDownloadInfo();
                info.setURL(download.URL);
                info.setPostData(new byte[]{});

                download.ID = Manager.addNew(info);
                download.Name = Manager.getName(download.ID);
                download.Size = Manager.getSize(download.ID);

                Log.d("gophast", "Started download " + download.Name);

                if (download.Size < 0) {
                    Log.d("gophast", "size < 0");
                    return Long.valueOf(-1);
                }

                handler.post(new Runnable() {
                    @Override
                    public void run() {
                        download.Downloaded = Manager.getDownloaded(download.ID);
                        publishProgress(download.Downloaded);
                        if (download.Downloaded == download.Size) {
                            return;
                        }

                        handler.postDelayed(this, 50);
                    }
                });

                Manager.waitDownload(download.ID);
                Log.d("gophast", "Finished download " + download.Name);
            } catch (Exception e) {
                Log.d("gophast", "Failed to add download");
                e.printStackTrace();
            }
            // Escape early if cancel() is called
            if (isCancelled()) break;
        }

        return size;
    }

    @Override
    protected void onProgressUpdate(Long... progress) {
        super.onProgressUpdate(progress);
        gophast.adapter.notifyDataSetChanged();
    }

    @Override
    protected void onPostExecute(Long result) {
        super.onPostExecute(result);
        Log.d("gophast", "Finished downloading " + result + " bytes " + download.Downloaded);
        onFinish.run();
    }

    private GoPhast getApp() {
        return gophast;
    }
}
