package space.rocketnine.gophast;

import android.app.Application;
import android.os.Environment;
import android.os.Handler;
import android.os.Looper;
import android.os.StrictMode;
import android.util.DisplayMetrics;
import android.widget.Toast;

import java.io.File;
import java.util.ArrayList;

public class GoPhast extends Application {
    ArrayList<Download> downloads;
    DownloadAdapter adapter;

    @Override
    public void onCreate() {
        super.onCreate();

        StrictMode.VmPolicy.Builder builder = new StrictMode.VmPolicy.Builder();
        StrictMode.setVmPolicy(builder.build());

        try {
            manager.Manager.initialize(2);
        } catch (Exception e) {
            e.printStackTrace();
            return;
        }

        manager.Manager.setDownloadDir(Environment.getExternalStoragePublicDirectory(Environment.DIRECTORY_DOWNLOADS).getAbsolutePath());

        downloads = new ArrayList<Download>();
        adapter = new DownloadAdapter(GoPhast.this, downloads);
    }

    void addDownload(String url) {
        url = url.trim();

        Download download = new Download();
        download.URL = url;
        download.Name = (new File(url)).getName();

        downloads.add(download);

        final DownloadTask task = new DownloadTask();
        task.gophast = GoPhast.this;
        task.onFinish = new Runnable() {
            @Override
            public void run() {
                longToast(task.download.Name + " finished");
            }
        };
        task.execute(download);
    }

    void shortToast(final String message) {
        new Handler(Looper.getMainLooper()).post(new Runnable() {
            @Override
            public void run() {
                Toast.makeText(GoPhast.this, message, Toast.LENGTH_SHORT).show();
            }
        });
    }

    void longToast(final String message) {
        new Handler(Looper.getMainLooper()).post(new Runnable() {
            @Override
            public void run() {
                Toast.makeText(GoPhast.this, message, Toast.LENGTH_LONG).show();
            }
        });
    }



    /**
     * This method converts dp unit to equivalent pixels, depending on device density.
     *
     * @param dp A value in dp (density independent pixels) unit. Which we need to convert into pixels
     * @return A float value to represent px equivalent to dp depending on device density
     */
    public int convertDpToPixel(int dp){
        return (int)(dp * ((float) getResources().getDisplayMetrics().densityDpi / DisplayMetrics.DENSITY_DEFAULT));
    }

    /**
     * This method converts device specific pixels to density independent pixels.
     *
     * @param px A value in px (pixels) unit. Which we need to convert into db
     * @return A float value to represent dp equivalent to px value
     */
    public int convertPixelsToDp(int px){
        return (int)(px / ((float) getResources().getDisplayMetrics().densityDpi / DisplayMetrics.DENSITY_DEFAULT));
    }
}
