package space.rocketnine.gophast;

import android.Manifest;
import android.content.DialogInterface;
import android.content.Intent;
import android.content.pm.PackageManager;
import android.os.Build;
import android.os.Bundle;
import android.support.v7.app.AlertDialog;
import android.support.v7.app.AppCompatActivity;
import android.util.Log;
import android.view.View;
import android.widget.AdapterView;
import android.widget.EditText;
import android.widget.LinearLayout;
import android.widget.ListView;

public class MainActivity extends AppCompatActivity {
    private GoPhast gophast;

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_main);
        getSupportActionBar().setDisplayShowHomeEnabled(true);
        getSupportActionBar().setIcon(R.mipmap.ic_launcher);
        getSupportActionBar().setBackgroundDrawable(getResources().getDrawable(R.drawable.road));

        if (Build.VERSION.SDK_INT >= Build.VERSION_CODES.M) {
            if (checkSelfPermission(Manifest.permission.WRITE_EXTERNAL_STORAGE) != PackageManager.PERMISSION_GRANTED) {
                requestPermissions(new String[]{Manifest.permission.WRITE_EXTERNAL_STORAGE}, 1337);
                finish();
                return;
            }
        }

        ListView lstDownloads = findViewById(R.id.lstDownloads);
        lstDownloads.setOnItemClickListener(new AdapterView.OnItemClickListener() {
            @Override
            public void onItemClick(AdapterView<?> parent, View view, int position, long arg3) {
                Download d = getApp().downloads.get(position);
                if (d != null) {
                    Intent intent = new Intent();
                    intent.setAction(android.content.Intent.ACTION_VIEW);
                    intent.setDataAndType(d.getPath(), d.getMIME());
                    intent.addFlags(Intent.FLAG_ACTIVITY_NEW_TASK);

                    try {
                        startActivityForResult(intent, 31337);
                    } catch (Exception e) {
                        e.printStackTrace();
                        getApp().longToast("No application able to open this file is installed");
                    }
                }
            }
        });
        lstDownloads.setAdapter(getApp().adapter);

        Log.d("gophast", "Create intent: " + getIntent().toString());
        Intent intent = getIntent();
        if (intent.getAction() != null && intent.getAction().equals("android.intent.action.VIEW") && intent.getData() != null) {
            getApp().addDownload(intent.getData().toString());
        }
    }

    public void newDownload(View view) {
        AlertDialog.Builder alert = new AlertDialog.Builder(MainActivity.this);
        final EditText edittext = new EditText(MainActivity.this);
        edittext.setHint(R.string.url);
        alert.setTitle(R.string.addDownload);
        alert.setView(edittext);
        alert.setPositiveButton(R.string.add, new DialogInterface.OnClickListener() {
            public void onClick(DialogInterface dialog, int whichButton) {
                String url = edittext.getText().toString();
                if (!url.trim().equals("") && url.trim().startsWith("http")) {
                    getApp().addDownload(url);
                    dialog.dismiss();
                } else {
                    getApp().longToast(getString(R.string.invalidURL));
                }
            }
        });
        alert.setNegativeButton(android.R.string.cancel, new DialogInterface.OnClickListener() {
            public void onClick(DialogInterface dialog, int whichButton) {
                dialog.dismiss();
            }
        });
        alert.show();
    }

    @Override
    protected void onNewIntent(Intent intent) {
        setIntent(intent);
        if (intent.getAction() != null && intent.getAction().equals("android.intent.action.VIEW") && intent.getData() != null) {
            Log.d("gophast", "New intent: " + intent.toString());
            getApp().addDownload(intent.getData().toString());
        }
    }

    private GoPhast getApp() {
        if (gophast == null) {
            gophast = (GoPhast)getApplication();
        }

        return gophast;
    }
}